Learn R Programming

BIOdry (version 0.2)

PTclim05: Meteorological records of precipitation and temperature

Description

Monthly precipitation sums and average temperatures of two climatic locations.

Usage

data(PTclim05)

Arguments

Details

Recorded months begin at January and end at December, and observed years span from 1951 to 2005. Factor in dataset defines one sample level (plot)

References

Bogino, S., and Bravo, F. (2008). Growth response of Pinus pinaster Ait. to climatic variables in central Spanish forests. Ann. For. Sci. 65, 1-13.

Examples

Run this code
str(PTclim05)

Run the code above in your browser using DataLab