Radial increments of Pinus pinaster from
tow sample plots located on Northern and Southern portions of Ebro
river basin, Spain.
Usage
data(Prings05)
Arguments
Details
This dataset
contains eight series of tree-ring widths of maritime
pine (Pinus pinaster), with recorded years spanning from 1810
to 2005. The cores were sampled
from dominant trees of two sites, with sample plots being located on
both: northern Spain (plot code: P44005) and center-east portion of
the same country (plot code: P16106). Two trees were selected by plot,
and two core samples were extracted by tree. Consequently, the sample
design defined three levels: sample in tree on plot (plot level),
sample in tree (tree level), and sample level.
References
Bogino, S., and Bravo, F. (2008). Growth response of Pinus pinaster Ait. to climatic variables in central Spanish forests. Ann. For. Sci. 65, 1-13.